@@ -39,8 +39,8 @@ class Geometry:
 
         script = Script(name=name, route_geometry=path_to_geometry_folder, route_cst=path_to_CST_project)
 
-
-        stream = os.popen(f'"{path_to_CST_DE}" -m "{os.path.abspath('script.bas')}"')
+        path_to_script = os.path.abspath('script.bas')
+        stream = os.popen(f'"{path_to_CST_DE}" -m "{path_to_script}"')
         script.remove_script()
         return stream.read()
 
